@@ -15,14 +15,18 @@ html_theme = "sphinx_rtd_theme"
 
 html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
 
+def setup(app):
+    app.add_stylesheet("main_stylesheet.css")
+
 extensions = ['breathe']
 breathe_projects = { 'xtensor': '../xml' }
 templates_path = ['_templates']
+html_static_path = ['_static']
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'xtensor'
-copyright = '2016, Johan Mabille and Sylvain Corlay'
-author = 'Johan Mabille and Sylvain Corlay'
+copyright = '2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht'
+author = 'Johan Mabille, Sylvain Corlay and Wolf Vollprecht'
 
 html_logo = 'quantstack-white.svg'
 
@@ -32,3 +36,6 @@ pygments_style = 'sphinx'
 todo_include_todos = False
 htmlhelp_basename = 'xtensordoc'
 
+html_js_files = [
+    'goatcounter.js'
+]
